@@ -1936,17 +1936,27 @@ bool RPolyline::mirror(const RLine& axis) {
 }
 
 bool RPolyline::reverse() {
+    QList<RVector> vs = vertices;
+    if (closed) {
+        vs.append(vs.first());
+    }
+
     RPolyline nPolyline;
-    QList<QSharedPointer<RShape> > segments = getExploded();
+
+    for (int i=vs.count()-1, k=0; i>=0; i--, k++) {
+        nPolyline.appendVertex(vs[i]);
+        if (i>0) {
+            nPolyline.setBulgeAt(k, -bulges[i-1]);
+
+            nPolyline.setStartWidthAt(k, endWidths[i-1]);
+            nPolyline.setEndWidthAt(k, startWidths[i-1]);
+        }
 
-    for (int i=segments.count()-1; i>=0; i--) {
-        QSharedPointer<RShape> seg = segments.at(i);
-        seg->reverse();
-        nPolyline.appendShape(*seg);
     }
     if (closed) {
         nPolyline.convertToClosed();
     }
+
     *this = nPolyline;
 
     Q_ASSERT(vertices.length()==bulges.length());
@@ -2255,6 +2265,13 @@ RPolyline RPolyline::roundAllCorners(double radius) const {
     return *this;
 }
 
+RPolyline RPolyline::getPolygon(double segmentLength) const {
+    if (polylineProxy!=NULL) {
+        return polylineProxy->getPolygon(*this, segmentLength);
+    }
+    return *this;
+}
+
 RPolyline RPolyline::getPolygonHull(double angle, double tolerance, bool inner) const {
     if (polylineProxy!=NULL) {
         return polylineProxy->getPolygonHull(*this, angle, tolerance, inner);
